@@ -84,6 +84,7 @@ my %hierarchy = (
     'GrayScaleEffect' => 'ImageTransformEffect',
     'GroupShape' => 'ShapeBase',
     'GroupingCharacterElement' => 'MathElement',
+    'HandoutLayoutingOptions' => 'SlidesLayoutOptions',
     'HeaderFooter' => 'ResourceBase',
     'HslEffect' => 'ImageTransformEffect',
     'Html5ExportOptions' => 'ExportOptions',
@@ -106,6 +107,7 @@ my %hierarchy = (
     'MoveToPathSegment' => 'PathSegment',
     'NaryOperatorElement' => 'MathElement',
     'NoFill' => 'FillFormat',
+    'NotesCommentsLayoutingOptions' => 'SlidesLayoutOptions',
     'NotesSlide' => 'ResourceBase',
     'NotesSlideHeaderFooter' => 'ResourceBase',
     'OleObjectFrame' => 'ShapeBase',
@@ -281,6 +283,7 @@ my %determiners = (
     'GrayScaleEffect' => { 'Type' => 'GrayScale', },
     'GroupShape' => { 'Type' => 'GroupShape', },
     'GroupingCharacterElement' => { 'Type' => 'GroupingCharacter', },
+    'HandoutLayoutingOptions' => { 'LayoutType' => 'Handout', },
     'HeaderFooter' => {  },
     'HslEffect' => { 'Type' => 'Hsl', },
     'Html5ExportOptions' => { 'Format' => 'html5', },
@@ -318,6 +321,7 @@ my %determiners = (
     'NaryOperatorElement' => { 'Type' => 'NaryOperator', },
     'NoFill' => { 'Type' => 'NoFill', },
     'NormalViewRestoredProperties' => {  },
+    'NotesCommentsLayoutingOptions' => { 'LayoutType' => 'NotesComments', },
     'NotesSlide' => {  },
     'NotesSlideExportFormat' => {  },
     'NotesSlideHeaderFooter' => {  },
@@ -397,6 +401,7 @@ my %determiners = (
     'SlideShowProperties' => {  },
     'SlideShowTransition' => {  },
     'Slides' => {  },
+    'SlidesLayoutOptions' => {  },
     'SmartArt' => { 'Type' => 'SmartArt', },
     'SmartArtNode' => {  },
     'SmartArtShape' => { 'Type' => 'SmartArtShape', },
